Struct amazon_sp_aplus_content::models::post_content_document_response_all_of::PostContentDocumentResponseAllOf
source · [−]pub struct PostContentDocumentResponseAllOf {
pub content_reference_key: String,
}Fields
content_reference_key: StringA unique reference key for the A+ Content document. A content reference key cannot form a permalink and may change in the future. A content reference key is not guaranteed to match any A+ content identifier.
Implementations
sourceimpl PostContentDocumentResponseAllOf
impl PostContentDocumentResponseAllOf
pub fn new(content_reference_key: String) -> PostContentDocumentResponseAllOf